# Changelog

All notable changes to this project will be documented in `docs/changelog.mdx`.

This project aims to adhere to [Keep a Changelog](https://keepachangelog.com/en/1.1.0/) and [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

For detailed release notes and migration guides, see `docs/changelog.mdx`.
